@@ -16,7 +16,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 
 from mypvdevices.DcsConnection import DcsConnection
 
-BUILDNR = "1.2104.12"
+BUILDNR = "1.2110.4"
 
 JOINTIMEOUT = 5
 SERIALLEN = 16
@@ -35,6 +35,7 @@ class ModbusDevice:
     __data__ = None
     __logdata__ = None
     __logdataTimeStamp__ = None
+    __logdataStartTimeStamp__ = None
     __logdataCounter__ = None
     __logdataLastValue__ = None
     __logdataSum__ = None
@@ -453,6 +454,16 @@ class ModbusDevice:
             logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " no datasets defined")
         self.__logdataTimeStamp__ = self.__registerTimeStamp__
 
+        if self.__logdataStartTimeStamp__ == None:
+            self.__logdataStartTimeStamp__ = datetime.now()
+    
+    def getlogdataage(self):
+        if self.__logdataStartTimeStamp__ != None:
+            difference = datetime.now() - self.__logdataStartTimeStamp__
+            return difference.total_seconds()
+        else:
+            return 0
+
     def __addtologdata__(self, datasetname, register):
         datasettype = self.__datasets__[datasetname][1]
         value = None
@@ -522,6 +533,7 @@ class ModbusDevice:
         self.__logdataCounter__.clear()
         self.__logdataSum__.clear()
         self.__logdataTimeStamp__ = None
+        self.__logdataStartTimeStamp__ = None
 
     def showinfo(self):
         if self.__datasets__ != None:
